/**
*************************************************************************************************************
*
*   \file main.c
*
*   Main module of the TWI Master interface
*
*   Main module is used to test the TWI master interface.\n
*   \n
*   \b Shortcut:    MAI
*
*   \author         Ralf Hochhausen
*   \date           26.05.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   22.04.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/
#include <compat\ina90.h>
#include "systime.h"				/* Include system time tick module */
#include "timer.h"					/* Include software timer module */
#include "nmeadll.h"				/* Include NMEA data link layer driver */
#include "nmeaparser.h"				/* Include NMEA parser module */

/*
*************************************************************************************************************
*   LOCAL DEFINITIIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL TYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL CONSTANTS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   STATIC VARIABLES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTION PROTOTYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTIONS
*************************************************************************************************************
*/

/**
*************************************************************************************************************
*
*   Basic initialization of the project
*
*   Function calls all init functions of the different modules and is responsible for
*	the basic initialization of the microcontroller.
*
*   \return             No return value
*   
*************************************************************************************************************
*/
static void vInitProject(void)
{
	SYST_vInit();
	TMR_vInit();
	NDLL_vInit();
	_SEI();				/* Globally enable interrupts */
}

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/**
*************************************************************************************************************
*
*   Main function
*
*   Function initializes the project and enters the main loop
*
*   \return             No return value
*   
*************************************************************************************************************
*/
int main (void)
{
	vInitProject();

	for(;;)
	{
		TMR_vHandleTask();
		NDLL_vHandleTask();
		NPAR_vHandleTask();
	}

	return 0;
}
