/**
*************************************************************************************************************
*
*   \file nmeaconv.c
*
*   NMEA Data conversion functions
*
*   Module contains all conversion functions which are used to convert and store the
*	data of the different NMEA frames.\n
*   \n
*   \b Shortcut:    NCONV
*
*   \author         Ralf Hochhausen
*   \date           23.06.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   23.06.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/
#include <avr/pgmspace.h>		/* Include ROM access functions */
#include "types.h"				/* Include basic types */
#include "nmeaconv.h"			/* Include own header */

/*
*************************************************************************************************************
*   LOCAL DEFINITIIONS
*************************************************************************************************************
*/
#define NCONV_DATA_DELIMITER	','		/* Datadelimiter within the NMEA frames */
#define NCONV_END_OF_NMEA_FRAME	0		/* End of NMEA frame is the \0 */

/*
*************************************************************************************************************
*   LOCAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL TYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL CONSTANTS
*************************************************************************************************************
*/
const tfpConvFunction NCONV_fpConvFunctionTable[] PROGMEM = 
{
	NCONV_ucConvertLatitude,
	NCONV_ucConvertLongitude,
	NCONV_ucConvertTime,
	NCONV_ucConvertStatus,
	NCONV_ucConvertVariable,
	NCONV_ucConvertFixedHEX,
	NCONV_ucConvertFixedAlpha,
	NCONV_ucConvertFixedNumber
};

/*
*************************************************************************************************************
*   STATIC VARIABLES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTION PROTOTYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTIONS
*************************************************************************************************************
*/



/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertLatitude(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertLatitude(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;
	
	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertLongitude(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertLongitude(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];
		
		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertTime(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertTime(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertStatus(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertStatus(uchar8 *pucData_, void *pTargetVar_)
{
	((uchar8 *)pTargetVar_)[0] = pucData_[0];
	((uchar8 *)pTargetVar_)[1] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertVariable(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertVariable(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertFixedHEX(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertFixedHEX(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertFixedAlpha(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertFixedAlpha(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}

/*
*************************************************************************************************************
*   uchar8 NCONV_ucConvertFixedNumber(uchar8 *pucData_, void *pTargetVar_)
*************************************************************************************************************
*/
uchar8 NCONV_ucConvertFixedNumber(uchar8 *pucData_, void *pTargetVar_)
{
	uchar8 ucIdx_ = 0;

	while(	pucData_[ucIdx_] != NCONV_DATA_DELIMITER
		 && pucData_[ucIdx_] != NCONV_END_OF_NMEA_FRAME)
	{
		((uchar8 *)pTargetVar_)[ucIdx_] = pucData_[ucIdx_];

		ucIdx_++;
	}

	((uchar8 *)pTargetVar_)[ucIdx_] = 0;

	return TRUE;
}
