/**
*************************************************************************************************************
*
*   \file nmeadll.h
*
*   NMEA data link layer.
*
*	Detects NMEA frames and writes them into the
*	internal buffer. Checksum is calculated. If checksum is wrong the
*	received frame is discarded. In case of a correct received frame
*	an event is generated to trigger frame parsing.\n
*
*   \n
*   \b Shortcut:    NDLL
*
*   \author         Ralf Hochhausen
*   \date           15.06.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   15.06.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

#ifndef __NDLL_H
#define __NDLL_H
/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL DEFINITIIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL TYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL CONSTANTS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/**
*************************************************************************************
*	\brief Function returns a pointer on the oldest unprocessed NMEA frame
*
*	It is necessary to check if any NMEA frame is in buffer first
*
*	\return		uchar8*	Pointer on the first element of the NMEA frame
*	
*************************************************************************************
*/
uchar8 *NDLL_pucGetReceivedNMEAFrame(void);

/**
*************************************************************************************
*	\brief Function releases the oldest NMEA frame from receive buffer
*
*	\return		void
*	
*************************************************************************************
*/
void NDLL_vReleaseFrameFromBuffer(void);

/**
*************************************************************************************
*	\brief Function can be used to check if any Frame is in th receive buffer
*
*	\return		uchar8	
*		TRUE	=>	NMEA message is in receive buffer
*		FALSE	=>	Receive buffer is empty
*
*************************************************************************************
*/
uchar8 NDLL_ucIsFrameInBuffer(void);

/**
*************************************************************************************
*	\brief Task handler of the NMEA DLL module
*
*	Handles protocol timeouts and the statemachine of the DLL
*	
*	\return	
*		void
*	
*************************************************************************************
*/
void NDLL_vHandleTask(void);

/**
*************************************************************************************
*	\brief Initialization of the nmea data link layer
*
*	Initialization of all module variables and the serial interface to the gps receiver
*	
*	\param		
*		void
*	
*************************************************************************************
*/
void NDLL_vInit(void);

#endif  /* __NDLL_H */
