/**
*************************************************************************************************************
*
*   \file nmeaframecfg.c
*
*   NMEA frame configuration
*
*   File contains the configuration of the NMEA protocol parser\n
*   \n
*   \b Shortcut:    NCFG
*
*   \author         Ralf Hochhausen
*   \date           23.06.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   23.06.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/
#include <avr/pgmspace.h>		/* Include ROM access functions */
#include "nmeaconv.h"			/* Include NMEA data converters */
#include "types.h"				/* Include basic types */
#include "nmeaframecfg.h"		/* Include own header */

/*
*************************************************************************************************************
*   LOCAL DEFINITIIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL TYPES
*************************************************************************************************************
*/
typedef struct
{
	uchar8	ucLatitude[10];
	uchar8	ucNS[2];
}tLatitude;

typedef struct
{
	uchar8	ucLongitude[11];
	uchar8	ucEW[2];
}tLongitude;

tLatitude	DBG_ucLatitude;
tLongitude	DBG_ucLongitude;
uchar8		DBG_ucTime[10];

/*
*************************************************************************************************************
*   LOCAL CONSTANTS
*************************************************************************************************************
*/

/**
*	Configuration of the NMEA sentence GPVTG
*/
const tNMEAFrameFormat NCFG_sNMEAFrame_VTG PROGMEM =
{
	"GPVTG",								/* Message identifier */
	7,										/* Number of data fields in the NMEA frame */
	{
		{ NCONV_TypeUndefined, NULL },		/* Configuration of the different data fields */
		{ NCONV_TypeUndefined, NULL },
		{ NCONV_TypeUndefined, NULL },
		{ NCONV_TypeUndefined, NULL },
		{ NCONV_TypeUndefined, NULL },
		{ NCONV_TypeUndefined, NULL },
		{ NCONV_TypeUndefined, NULL }
	}
};

/**
*	Configuration of the NMEA sentence GPGGA
*/
const tNMEAFrameFormat NCFG_sNMEAFrame_GGA PROGMEM =
{
	"GPGGA",										/* Message identifier */
	14,												/* Number of data fields in the NMEA frame */
	{
		/* Configuration of the different data fields */
		{ NCONV_TypeTime,		DBG_ucTime },
		{ NCONV_TypeLatitude,	DBG_ucLatitude.ucLatitude},
		{ NCONV_TypeStatus,		DBG_ucLatitude.ucNS},
		{ NCONV_TypeLongitude,	DBG_ucLongitude.ucLongitude},
		{ NCONV_TypeStatus,		DBG_ucLongitude.ucEW},
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL },
		{ NCONV_TypeUndefined,	NULL }
	}
};

/*
*	Configuration table of the supported NMEA frames
*/
const tNMEAFrameFormat *NCFG_asSupportedFrames [] PROGMEM =
{
	&NCFG_sNMEAFrame_GGA,
	&NCFG_sNMEAFrame_VTG
};

/*
*************************************************************************************************************
*   STATIC VARIABLES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTION PROTOTYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/
