/**
*************************************************************************************************************
*
*   \file nmeaframecfg.h
*
*   NMEA frame configuration
*
*   File contains the whole configuration of the NMEA protocol parser\n
*   \n
*   \b Shortcut:    NCFG
*
*   \author         Ralf Hochhausen
*   \date           23.06.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   23.06.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

#ifndef __NCFG_H
#define __NCFG_H
/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/
#include <avr/pgmspace.h>		/* Include ROM access functions */
#include "nmeaconv.h"			/* Include NMEA data converters */
#include "types.h"				/* Include basic types */

/*
*************************************************************************************************************
*   GLOBAL DEFINITIIONS
*************************************************************************************************************
*/
#define NCFG_SUPPORTED_FRAME_NO		2		/**< Number of supperted NMEA frames */

/*
*************************************************************************************************************
*   GLOBAL TYPES
*************************************************************************************************************
*/

/**
*	Type of a NMEA frame table entry
*/
typedef struct NMEAFrameFormat
{
	uchar8				ucMSG[5];			/**< Identifier of the NMEA message */
	uchar8				ucNoOfDataFields;	/**< Number of NMEA data items */
	tNMEADataConnector	sDataConnection[];	/**< List with all NMEA message content types */
}tNMEAFrameFormat;

/*
*************************************************************************************************************
*   GLOBAL CONSTANTS
*************************************************************************************************************
*/

/* NMEA frame configuration table */
extern const tNMEAFrameFormat *NCFG_asSupportedFrames [] PROGMEM;

#endif  /* __NCFG_H */
