/**
*************************************************************************************************************
*
*   \file systime.c
*
*   Short file description
*
*   Long File description\n
*   \n
*   \b Shortcut:    SYST
*
*   \author         Ralf Hochhausen
*   \date           26.05.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   26.05.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial revision
*
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/
#include <avr\io.h>				/* Include IO register definitions */
#include <avr\interrupt.h>		/* Include interrupt/signal definitions */
#include "types.h"				/* Include generic type definitions */
#include "systime.h"			/* Include own header */

/*
*************************************************************************************************************
*   LOCAL DEFINITIIONS
*************************************************************************************************************
*/
#define SYST_BASETICK_INCR	(SYST_BASETICK_TIME_100NS / SYST_BASETICKS_PER_TMR_CLK)

/*
*************************************************************************************************************
*   LOCAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL TYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL CONSTANTS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   STATIC VARIABLES
*************************************************************************************************************
*/
TickHandler SYST_fpTickHandlerFct = NULL;

/*
*************************************************************************************************************
*   LOCAL FUNCTION PROTOTYPES
*************************************************************************************************************
*/


/*
*************************************************************************************************************
*   LOCAL FUNCTIONS
*************************************************************************************************************
*/
ISR(SIG_OUTPUT_COMPARE1A)
{
	OCR1A	+= SYST_BASETICK_INCR;			/* Configure next tick interrupt */
	
	if(SYST_fpTickHandlerFct != NULL)			/* Call tick handler only if a function has been registered */
	{
		SYST_fpTickHandlerFct();
	}
}

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   void SYST_vRegisterTickHandler(TickHandler fpTickFct_)
*************************************************************************************************************
*/
void SYST_vRegisterTickHandler(TickHandler fpTickFct_)
{
	SYST_fpTickHandlerFct = fpTickFct_;
}

/*
*************************************************************************************************************
*   void SYST_vInit(void)
*************************************************************************************************************
*/
void SYST_vInit(void)
{
	TCNT1	= 0x0000;				/* Reset timer/counter 1*/

	TCCR1A	= 0x00;					/* Configure timer/counter1 control register A */
									/* Output compare mode for channel A/B/C */
									/* Normal operation OCnA/OCnB/OCnC disconnected */
									/* Waveform generation mode normal */
	
	OCR1A	= SYST_BASETICK_INCR;	/* Configure first compare interrupt */
	
	TIFR	|= (1 << OCF1A);		/* Reset output compare flag by writing logical '1' */
	TIMSK	|= (1 << OCIE1A);		/* Enable output compare interrupt */

	TCCR1B	= 0x03;					/* Configure timer/counter1 control register B */
									/* Input capture noise canceler disabled */
									/* Input capture edge select: Not relevant */
									/* Waveform generation mode normal */
									/* Clock select: clk/64 */
}
