/**
*************************************************************************************************************
*
*   \file systime.h
*
*   Short file description
*
*   Long File description\n
*   \n
*   \b Shortcut:    SYST
*
*   \author         Ralf Hochhausen
*   \date           26.05.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   26.05.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

#ifndef __SYST_H
#define __SYST_H
/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL DEFINITIIONS
*************************************************************************************************************
*/

/**
*	\brief	Number of base ticks per timer clock
*
*	Microcontrollers may have different possible prescaler settings and may operate at various
*	crystal frequencies. For this reason all system times are counted in multiples of 100ns.
*	This time is called system base time quantum.
*/
#define SYST_BASETICKS_PER_TMR_CLK	40

/**
*	\brief	Configuration of base tick interrupt time
*	
*	This time is measured in multiples of the system
*	base time quantum.
*/
#define SYST_BASETICK_TIME_100NS	100000

/*
*************************************************************************************************************
*   GLOBAL MACROS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL TYPES
*************************************************************************************************************
*/

/**
*	Type of the tick ISR function
*/
typedef void (*TickHandler)(void);

/*
*************************************************************************************************************
*   GLOBAL CONSTANTS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   LOCAL FUNCTION PROTOTYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/**
*************************************************************************************************************
*
*   \brief Register tick handler function
*
*	Function registers a tick handler function which is called in every tick ISR
*
*	\param		fpTickFct_	Pointer to the handler function which has to be called in tick ISR
*
*   \return		void
*   
*************************************************************************************************************
*/
void SYST_vRegisterTickHandler(TickHandler fpTickFct_);

/**
*************************************************************************************************************
*
*   \brief Initialize sytem time module.
*
*	Function initializes the hardware timer which generates the system time base.
*
*   \return		void
*   
*************************************************************************************************************
*/
void SYST_vInit(void);

#endif  /* __SYST_H */
