/**
*************************************************************************************************************
*
*   \file utility.h
*
*   Generic utilities
*
*   \n
*   \n
*   \b Shortcut:    UTI
*
*   \author         Ralf Hochhausen
*   \date           15.06.2006
*   \version        1.0
*
*   (c) 2006 by Ralf Hochhausen (e-mail: micro@ralf-hochhausen.de)
*
*   This program is free software; you can redistribute it and/or
*   modify it under the terms of the GNU General Public License
*   as published by the Free Software Foundation; either version 2
*   of the License, or (at your option) any later version.
*   
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details.
*   
*   You should have received a copy of the GNU General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*   \b History:
*
*   15.06.2006      Ralf Hochhausen\n
*                   Revision 1.0\n
*                   Initial Revision
*
*************************************************************************************************************
*/

#ifndef __UTI_H
#define __UTI_H
/*
*************************************************************************************************************
*   INCLUDES 
*************************************************************************************************************
*/

#include "types.h"				/* Include generic type definitions */

/*
*************************************************************************************************************
*   GLOBAL DEFINITIIONS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL MACROS
*************************************************************************************************************
*/

/**
*	Extract low nibble out of an 8 bit character
*/
#define UTI_mGetLowNibble(Value)	((uchar8)((uchar8)Value & 0x0F))

/**
*	Extract high nibble out of an 8 bit character
*/
#define UTI_mGetHighNibble(Value)	((uchar8)(((uchar8)Value & 0xF0) >> 4))

/**
*	Extract low byte out of an 16 bit unsigned integer
*/
#define UTI_mGetLowByte(Value)		((uchar8)((uint16)Value & 0x00FF))

/**
*	Extract high byte out of an 16 bit unsigned integer
*/
#define UTI_mGetHighByte(Value)		((uchar8)(((uint16)Value & 0xFF00) >> 8))

/*
*************************************************************************************************************
*   GLOBAL TYPES
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL CONSTANTS
*************************************************************************************************************
*/

/*
*************************************************************************************************************
*   GLOBAL FUNCTIONS
*************************************************************************************************************
*/

/**
*************************************************************************************************************
*	\brief	Conversion from number to Ascii sign
*
*	Function converts the given number into the corresponding hexadecimal ASCII character.\n
*	=> 0..15	->	0..F
*	
*	\return	
*		void
*
*	\param		
*		ucByte_		[0..15] Number to convert
*
*	\remark	The range of the input variable is not checked!
*	
*************************************************************************************************************
*/
uchar8 UTI_ucConvHexNumberToAscii(uchar8 ucByte_);

#endif  /* __UTI_H */
